@@ -46,6 +46,7 @@ class Config
         'sort-packages' => false,
         'optimize-autoloader' => false,
         'classmap-authoritative' => false,
+        'apcu-autoloader' => false,
         'prepend-autoloader' => true,
         'github-domains' => array('github.com'),
         'bitbucket-expose-hostname' => true,
@@ -59,15 +60,17 @@ class Config
         'platform' => array(),
         'archive-format' => 'tar',
         'archive-dir' => '.',
+        'htaccess-protect' => true,
         // valid keys without defaults (auth config stuff):
         // bitbucket-oauth
         // github-oauth
         // gitlab-oauth
+        // gitlab-token
         // http-basic
     );
 
     public static $defaultRepositories = array(
-        'packagist' => array(
+        'packagist.org' => array(
             'type' => 'composer',
             'url' => 'https?://packagist.org',
             'allow_ssl_downgrade' => true,
@@ -77,7 +80,9 @@ class Config
     private $config;
     private $baseDir;
     private $repositories;
+    /** @var ConfigSourceInterface */
     private $configSource;
+    /** @var ConfigSourceInterface */
     private $authConfigSource;
     private $useEnvironment;
     private $warnedHosts = array();
@@ -125,7 +130,7 @@ class Config
         // override defaults with given config
         if (!empty($config['config']) && is_array($config['config'])) {
             foreach ($config['config'] as $key => $val) {
-                if (in_array($key, array('bitbucket-oauth', 'github-oauth', 'gitlab-oauth', 'http-basic')) && isset($this->config[$key])) {
+                if (in_array($key, array('bitbucket-oauth', 'github-oauth', 'gitlab-oauth', 'gitlab-token', 'http-basic')) && isset($this->config[$key])) {
                     $this->config[$key] = array_merge($this->config[$key], $val);
                 } elseif ('preferred-install' === $key && isset($this->config[$key])) {
                     if (is_array($val) || is_array($this->config[$key])) {
@@ -157,13 +162,13 @@ class Config
             foreach ($newRepos as $name => $repository) {
                 // disable a repository by name
                 if (false === $repository) {
-                    unset($this->repositories[$name]);
+                    $this->disableRepoByName($name);
                     continue;
                 }
 
                 // disable a repository with an anonymous {"name": false} repo
                 if (is_array($repository) && 1 === count($repository) && false === current($repository)) {
-                    unset($this->repositories[key($repository)]);
+                    $this->disableRepoByName(key($repository));
                     continue;
                 }
 
@@ -171,7 +176,11 @@ class Config
                 if (is_int($name)) {
                     $this->repositories[] = $repository;
                 } else {
-                    $this->repositories[$name] = $repository;
+                    if ($name === 'packagist') { // BC support for default "packagist" named repo
+                        $this->repositories[$name . '.org'] = $repository;
+                    } else {
+                        $this->repositories[$name] = $repository;
+                    }
                 }
             }
             $this->repositories = array_reverse($this->repositories, true);
@@ -207,11 +216,12 @@ class Config
             case 'cache-vcs-dir':
             case 'cafile':
             case 'capath':
+            case 'htaccess-protect':
                 // convert foo-bar to COMPOSER_FOO_BAR and check if it exists since it overrides the local config
                 $env = 'COMPOSER_' . strtoupper(strtr($key, '-', '_'));
 
                 $val = $this->getComposerEnv($env);
-                $val = rtrim($this->process(false !== $val ? $val : $this->config[$key], $flags), '/\\');
+                $val = rtrim((string) $this->process(false !== $val ? $val : $this->config[$key], $flags), '/\\');
                 $val = Platform::expandPath($val);
 
                 if (substr($key, -4) !== '-dir') {
@@ -352,9 +362,9 @@ class Config
     /**
      * Replaces {$refs} inside a config string
      *
-     * @param  string $value a config string that can contain {$refs-to-other-config}
-     * @param  int    $flags Options (see class constants)
-     * @return string
+     * @param  string|int|null $value a config string that can contain {$refs-to-other-config}
+     * @param  int             $flags Options (see class constants)
+     * @return string|int|null
      */
     private function process($value, $flags)
     {
@@ -404,6 +414,15 @@ class Config
         return false;
     }
 
+    private function disableRepoByName($name)
+    {
+        if (isset($this->repositories[$name])) {
+            unset($this->repositories[$name]);
+        } elseif ($name === 'packagist') { // BC support for default "packagist" named repo
+            unset($this->repositories['packagist.org']);
+        }
+    }
+
     /**
      * Validates that the passed URL is allowed to be used by current config, or throws an exception.
      *
