@@ -12,12 +12,14 @@
 
 namespace Composer\Downloader;
 
+use Composer\Package\Archiver\ArchivableFilesFinder;
 use Composer\Package\Dumper\ArrayDumper;
 use Composer\Package\PackageInterface;
 use Composer\Package\Version\VersionGuesser;
 use Composer\Package\Version\VersionParser;
 use Composer\Util\Platform;
 use Composer\Util\ProcessExecutor;
+use Composer\Util\Filesystem as ComposerFilesystem;
 use Symfony\Component\Filesystem\Exception\IOException;
 use Symfony\Component\Filesystem\Filesystem;
 
@@ -118,8 +120,12 @@ class PathDownloader extends FileDownloader implements VcsCapableDownloaderInter
 
         // Fallback if symlink failed or if symlink is not allowed for the package
         if (self::STRATEGY_MIRROR == $currentStrategy) {
+            $fs = new ComposerFilesystem();
+            $realUrl = $fs->normalizePath($realUrl);
+
             $this->io->writeError(sprintf('%sMirroring from %s', $isFallback ? '    ' : '', $url), false);
-            $fileSystem->mirror($realUrl, $path);
+            $iterator = new ArchivableFilesFinder($realUrl, array());
+            $fileSystem->mirror($realUrl, $path, $iterator);
         }
 
         $this->io->writeError('');
