@@ -116,16 +116,15 @@ class Perforce
 
     protected function executeCommand($command)
     {
-        $this->commandResult = "";
-        $exit_code = $this->process->execute($command, $this->commandResult);
+        $this->commandResult = '';
 
-        return $exit_code;
+        return $this->process->execute($command, $this->commandResult);
     }
 
     public function getClient()
     {
         if (!isset($this->p4Client)) {
-            $cleanStreamName = str_replace('@', '', str_replace('/', '_', str_replace('//', '', $this->getStream())));
+            $cleanStreamName = str_replace(array('//', '/', '@'), array('', '_', ''), $this->getStream());
             $this->p4Client = 'composer_perforce_' . $this->uniquePerforceClientName . '_' . $cleanStreamName;
         }
 
@@ -189,9 +188,7 @@ class Perforce
 
     public function getP4ClientSpec()
     {
-        $p4clientSpec = $this->path . '/' . $this->getClient() . '.p4.spec';
-
-        return $p4clientSpec;
+        return $this->path . '/' . $this->getClient() . '.p4.spec';
     }
 
     public function getUser()
@@ -246,13 +243,13 @@ class Perforce
             }
 
             return null;
-        } else {
-            $command = 'echo $' . $name;
-            $this->executeCommand($command);
-            $result = trim($this->commandResult);
-
-            return $result;
         }
+
+        $command = 'echo $' . $name;
+        $this->executeCommand($command);
+        $result = trim($this->commandResult);
+
+        return $result;
     }
 
     public function queryP4Password()
@@ -276,8 +273,7 @@ class Perforce
         if ($useClient) {
             $p4Command = $p4Command . '-c ' . $this->getClient() . ' ';
         }
-        $p4Command = $p4Command . '-p ' . $this->getPort() . ' ';
-        $p4Command = $p4Command . $command;
+        $p4Command = $p4Command . '-p ' . $this->getPort() . ' ' . $command;
 
         return $p4Command;
     }
@@ -285,7 +281,7 @@ class Perforce
     public function isLoggedIn()
     {
         $command = $this->generateP4Command('login -s', false);
-        $exitCode  = $this->executeCommand($command);
+        $exitCode = $this->executeCommand($command);
         if ($exitCode) {
             $errorOutput = $this->process->getErrorOutput();
             $index = strpos($errorOutput, $this->getUser());
@@ -304,7 +300,9 @@ class Perforce
 
     public function connectClient()
     {
-        $p4CreateClientCommand = $this->generateP4Command('client -i < ' . str_replace(" ", "\\ ", $this->getP4ClientSpec()));
+        $p4CreateClientCommand = $this->generateP4Command(
+            'client -i < ' . str_replace(" ", "\\ ", $this->getP4ClientSpec())
+        );
         $this->executeCommand($p4CreateClientCommand);
     }
 
@@ -397,55 +395,55 @@ class Perforce
 
     public function getComposerInformation($identifier)
     {
-        $index = strpos($identifier, '@');
-        if ($index === false) {
-            $composerJson = $identifier. '/composer.json';
+        $composerFileContent = $this->getFileContent('composer.json', $identifier);
 
-            return $this->getComposerInformationFromPath($composerJson);
+        if (!$composerFileContent) {
+            return;
         }
 
-        return $this->getComposerInformationFromLabel($identifier, $index);
+        return json_decode($composerFileContent, true);
     }
 
-    public function getComposerInformationFromPath($composerJson)
+    public function getFileContent($file, $identifier)
     {
-        $command = $this->generateP4Command(' print ' . $composerJson);
+        $path = $this->getFilePath($file, $identifier);
+
+        $command = $this->generateP4Command(' print ' . $path);
         $this->executeCommand($command);
         $result = $this->commandResult;
-        $index = strpos($result, '{');
-        if ($index === false) {
-            return '';
-        }
-        if ($index >= 0) {
-            $rawData = substr($result, $index);
-            $composer_info = json_decode($rawData, true);
 
-            return $composer_info;
+        if (!trim($result)) {
+            return null;
         }
 
-        return '';
+        return $result;
     }
 
-    public function getComposerInformationFromLabel($identifier, $index)
+    public function getFilePath($file, $identifier)
     {
-        $composerJsonPath = substr($identifier, 0, $index) . '/composer.json' . substr($identifier, $index);
-        $command = $this->generateP4Command(' files ' . $composerJsonPath, false);
+        $index = strpos($identifier, '@');
+        if ($index === false) {
+            $path = $identifier. '/' . $file;
+
+            return $path;
+        }
+
+        $path = substr($identifier, 0, $index) . '/' . $file . substr($identifier, $index);
+        $command = $this->generateP4Command(' files ' . $path, false);
         $this->executeCommand($command);
         $result = $this->commandResult;
         $index2 = strpos($result, 'no such file(s).');
         if ($index2 === false) {
             $index3 = strpos($result, 'change');
-            if (!($index3 === false)) {
+            if ($index3 !== false) {
                 $phrase = trim(substr($result, $index3));
                 $fields = explode(' ', $phrase);
-                $id = $fields[1];
-                $composerJson = substr($identifier, 0, $index) . '/composer.json@' . $id;
 
-                return $this->getComposerInformationFromPath($composerJson);
+                return substr($identifier, 0, $index) . '/' . $file . '@' . $fields[1];
             }
         }
 
-        return "";
+        return null;
     }
 
     public function getBranches()
@@ -536,9 +534,8 @@ class Perforce
             return null;
         }
         $fields = explode(' ', $changes);
-        $changeList = $fields[1];
 
-        return $changeList;
+        return $fields[1];
     }
 
     /**
@@ -560,9 +557,8 @@ class Perforce
         $main = substr($fromReference, 0, $index) . '/...';
         $command = $this->generateP4Command('filelog ' . $main . '@' . $fromChangeList. ',' . $toChangeList);
         $this->executeCommand($command);
-        $result = $this->commandResult;
 
-        return $result;
+        return $this->commandResult;
     }
 
     public function getFilesystem()
